approximate_branch

Function approximate_branch 

pub fn approximate_branch(
    a: &SurfaceGeometry,
    b: &SurfaceGeometry,
    branch: &Traced,
    tolerance: f64,
    tol: Tolerances,
) -> OgeomResult<IntersectionCurve>
Fit one traced branch to curves, within tolerance.

Errors

OgeomError::Construction if the branch has fewer than two points or the tolerance is not a positive distance.