pub fn trace(
a: &SurfaceGeometry,
b: &SurfaceGeometry,
from: Contact,
options: Marching,
tol: Tolerances,
) -> OgeomResult<Traced>Expand description
Follow the intersection from a starting point, in both directions.
Errors
OgeomError::Construction if the settings are
unusable; OgeomError::NotDone if the two surfaces
are tangent at the seed, where there is no single direction to follow.